@@ -2,6 +2,7 @@
    ***                             dhelp                            *** 
    ***                    Debian online help system                 ***
    ********************************************************************
+   ***  Copyright (c) 2001-02 by Stefan Hornburg (Racke) <racke@linuxia.de>
    ***  Copyright (c) 1997-99 by Marco Budde (Budde@tu-harburg.de)  ***
    ***                         GNU GPL license                      ***
    ******************************************************************** */
@@ -18,7 +19,7 @@
 #include <sys/param.h>
 
 #if __GLIBC__ >= 2 && __GLIBC_MINOR__ >= 1
-  #include <db1/db.h>
+  #include <db_185.h>
 #else
   #include <db.h>
 #endif
@@ -325,15 +326,20 @@ void html_w_head (FILE *out, DB *tdb)
   clearerr (out);
  
   path_index_cwd (cwd);
-  db_title_read (tdb, cwd, zw2, sizeof (zw)); 
+  db_title_read (tdb, cwd, zw2, sizeof (zw));
+  if (strlen(zw2) == 0)
+	  {
+	  fprintf (stderr, "dhelp_parse: no title found for directory %s\n",
+			   cwd);
+	  }
   fprintf (out, "<HTML>\n\n<HEAD>\n<TITLE>%s</TITLE>\n"
-           "<LINK REV=made HREF=\"mailto:Budde@tu-harburg.de\">\n"
+           "<LINK REV=made HREF=\"mailto:dhelp@packages.debian.org\">\n"
            "</HEAD>\n\n", zw2);
   fprintf (out, "<BODY BGCOLOR=#FFFFFF>\n");
 
   path_relative (zw);
-  strcat (zw, "dhelp/debian.jpg");
-  fprintf (out, "<IMG SRC=\"%s\" ALT=\"Debian GNU/Linux\"> \n", zw);
+  fprintf (out, "<IMG SRC=\"%s%s\"> \n", zw, "dhelp/swirl.jpg");
+  fprintf (out, "<IMG SRC=\"%s%s\" ALT=\"Debian GNU/Linux\"> \n", zw, "dhelp/debian.jpg");
   fprintf (out, "<H1>%s</H1>\n<P>\n", zw2);
   fprintf (out, "<DL>\n");
 
@@ -375,7 +381,7 @@ void html_w_tail (FILE *out)
                 "</FORM><BR>\n"
                 "[ <A HREF=\"/cgi-bin/info2www\">%s</A> | \n"
                 "<A HREF=\"/cgi-bin/man2html\">%s</A> | \n"
-                "<A HREF=\"/doc/\">%s</A> ]\n</CENTER>\n",
+                "<A HREF=\"../\">%s</A> ]\n</CENTER>\n",
                 search[i], info[i], man[i], other[i]);
   fprintf (out, "</BODY></HTML>\n");
 
@@ -390,7 +396,7 @@ void html_w_item (tItem *item, FILE *out)
   clearerr (out);
 
   path_relative (zw);
-  fprintf (out, "<DT><IMG SRC=\"%sdhelp/text.gif\">"
+  fprintf (out, "<DT><IMG SRC=\"%sdhelp/text.png\">"
                 " <A HREF=\"%s%s\"><FONT FACE=\"Helvetica, Arial\">"
                 "<B>%s</B></FONT></A><P></DT>\n"
                 "    <DD>%s</DD>\n\n",
@@ -460,7 +466,7 @@ int html_w_dir_links (char *dirname, DB *tdb)
     if ((out = fopen (zw, "w")) == NULL)
     {
       fprintf (stderr, "dhelp_parse: can't open %s\n", zw);
-      return (1);
+      exit (1);
     }
     html_w_head (out, tdb);
   }
@@ -470,7 +476,7 @@ int html_w_dir_links (char *dirname, DB *tdb)
     if ((out = fopen (zw, "a")) == NULL)
     {
       fprintf (stderr, "dhelp_parse: can't open %s\n", zw);
-      return (1);
+      exit (1);
     }
   }
   dir = opendir (dirname);
@@ -487,7 +493,7 @@ int html_w_dir_links (char *dirname, DB *tdb)
       if (S_ISDIR (buf.st_mode))
       {
         path_relative (relpath);
-        fprintf (out, "<DT><IMG SRC=\"%sdhelp/folder.gif\">"
+        fprintf (out, "<DT><IMG SRC=\"%sdhelp/folder.png\" ALT=\"\">"
                  " <A HREF=\"%s/index.html\">"
                  "<FONT FACE=\"Helvetica, Arial\"><B>%s/</B></FONT>"
                  "</A></DT>\n"
@@ -519,13 +525,13 @@ void html_write (void)
 
   if ((db = db_open (O_RDONLY)) == NULL)
   {
-    fprintf (stderr, "dhelp_parse: can't open %s\n\n", DBNAME);
-    exit (0);
+    fprintf (stderr, "dhelp_parse: can't open %s\n", DBNAME);
+    exit (1);
   }
   if ((tdb = db_title_open (O_RDWR|O_CREAT)) == NULL)
   {
-    fprintf (stderr, "dhelp_parse: can't open %s\n\n", DBTITLE_NAME);
-    exit (0);
+    fprintf (stderr, "dhelp_parse: can't open %s\n", DBTITLE_NAME);
+    exit (1);
   }
 
   rm_r (INDEXROOT);
@@ -564,7 +570,7 @@ void html_write (void)
 
 
   
-int get_item (FILE *fd, char *filename, tItem *item)
+int get_item (char *dhelpfilename, FILE *fd, char *filename, tItem *item)
 {
   char zw[200];
   int  cnt = 0;
@@ -587,6 +593,11 @@ int get_item (FILE *fd, char *filename, tItem *item)
     if (strncmp ("<directory>", zw, 11) == 0) 
     {
       strncpy (item->dir, zw+11, sizeof (item->dir));
+	  if (item->dir[0] == '/')
+		  {
+		  printf ("dhelp_parse: %s.dhelp: directory entry starts with /\n", dhelpfilename);
+		  exit (1);
+		  }
       item->dir[sizeof(item->dir)-1] = '\0';
       strdel (item->dir);
     }
@@ -641,18 +652,18 @@ int dhelp_add (char *name)
 
   if ((in = fopen (name, "r")) == NULL)
   {
-    fprintf (stderr, "dhelp_parse: can't open %s\n\n", name);
-    return (1);
+    fprintf (stderr, "dhelp_parse: can't open %s\n", name);
+    exit (1);
   }
   if ((db = db_open (O_RDWR|O_CREAT)) == NULL)
   {
-    fprintf (stderr, "dhelp_parse: can't open %s\n\n", DBNAME);
-    return (1);
+    fprintf (stderr, "dhelp_parse: can't open %s\n", DBNAME);
+    exit (1);
   }
   if ((db_title = db_title_open (O_RDWR|O_CREAT)) == NULL)
   {
-    fprintf (stderr, "dhelp_parse: can't open %s\n\n", DBTITLE_NAME);
-    return (1);
+    fprintf (stderr, "dhelp_parse: can't open %s\n", DBTITLE_NAME);
+    exit (1);
   }
 
   /* relativen Pfad zum Dokument erzeugen */
@@ -663,7 +674,7 @@ int dhelp_add (char *name)
   file_ptr++;
   file_ptr [strlen(file_ptr)-6] = '\0';
   
-  while (!(get_item (in, file_ptr, &item)))
+  while (!(get_item (name, in, file_ptr, &item)))
   {
     if (item.file[0] != '\0')
       db_write (db, &item);
@@ -690,13 +701,13 @@ int dhelp_del (char *name)
 
   if ((in = fopen (name, "r")) == NULL)
   {
-    fprintf (stderr, "dhelp_parse: can't open %s\n\n", name);
-    return (1);
+    fprintf (stderr, "dhelp_parse: can't open %s\n", name);
+    exit (1);
   }
   if ((db = db_open (O_RDWR|O_CREAT)) == NULL)
   {
-    fprintf (stderr, "dhelp_parse: can't open %s\n\n", DBNAME);
-    return (1);
+    fprintf (stderr, "dhelp_parse: can't open %s\n", DBNAME);
+    exit (1);
   }
 
   /* relativen Pfad zum Dokument erzeugen */
@@ -707,7 +718,7 @@ int dhelp_del (char *name)
   file_ptr++;
   file_ptr [strlen(file_ptr)-6] = '\0';
   
-  while (!(get_item (in, file_ptr, &item)))
+  while (!(get_item (name, in, file_ptr, &item)))
     db_del (db, &item);
     
   fclose (in);
